from PythUnity.Classes import Object
from PythUnity.Classes import String
from PythUnity.Classes import Rect
from PythUnity.Functions import AddPrefab
from PythUnity.Functions import GetPrefab
from PythUnity.Functions import PrintFonts
from PythUnity.main import init
from PythUnity.help import help
import PythUnity.Variables
from pygame import image
from pygame import Surface
from pygame import font
v = Variables.var
del Variables